@@ -5,7 +5,7 @@ import copy
 import datetime
 import logging
 import time
-from typing import Awaitable, Iterator, List, Optional, Union
+from typing import Awaitable, Dict, Iterator, List, Optional, Union
 
 from eventkit import Event
 
@@ -260,11 +260,11 @@ class IB:
             host: Host name or IP address.
             port: Port number.
             clientId: ID number to use for this client; must be unique per
-                connection. Setting clientId=0 will automatically merge manual
-                TWS trading with this client.
+              connection. Setting clientId=0 will automatically merge manual
+              TWS trading with this client.
             timeout: If establishing the connection takes longer than
-                ``timeout`` seconds then the ``asyncio.TimeoutError`` exception
-                is raised. Set to 0 to disable timeout.
+              ``timeout`` seconds then the ``asyncio.TimeoutError`` exception
+              is raised. Set to 0 to disable timeout.
             readonly: Set to ``True`` when API is in read-only mode.
             account: Main account to receive updates for.
         """
@@ -654,7 +654,7 @@ class IB:
             order.orderId = orderId
             orderStatus = OrderStatus(
                 orderId=orderId, status=OrderStatus.PendingSubmit)
-            logEntry = TradeLogEntry(now, orderStatus.status, '')
+            logEntry = TradeLogEntry(now, orderStatus.status)
             trade = Trade(
                 contract, order, orderStatus, [], [logEntry])
             self.wrapper.trades[key] = trade
@@ -682,7 +682,7 @@ class IB:
                     newStatus = OrderStatus.Cancelled
                 else:
                     newStatus = OrderStatus.PendingCancel
-                logEntry = TradeLogEntry(now, newStatus, '')
+                logEntry = TradeLogEntry(now, newStatus)
                 trade.log.append(logEntry)
                 trade.orderStatus.status = newStatus
                 self._logger.info(f'cancelOrder: {trade}')
@@ -1442,7 +1442,7 @@ class IB:
     def calculateOptionPrice(
             self, contract: Contract,
             volatility: float, underPrice: float,
-            optPrcOptions=None) -> OptionComputation:
+            optPrcOptions: List[TagValue] = []) -> OptionComputation:
         """
         Calculate the option price given the volatility.
 
@@ -1611,7 +1611,8 @@ class IB:
             faDataType: See :meth:`.requestFA`.
             xml: The XML-formatted configuration string.
         """
-        self.client.replaceFA(faDataType, xml)
+        reqId = self.client.getReqId()
+        self.client.replaceFA(reqId, faDataType, xml)
 
     # now entering the parallel async universe
 
@@ -1619,6 +1620,7 @@ class IB:
             self, host: str = '127.0.0.1', port: int = 7497,
             clientId: int = 1, timeout: Optional[float] = 4,
             readonly: bool = False, account: str = ''):
+        clientId = int(clientId)
         self.wrapper.clientId = clientId
         timeout = timeout or None
         try:
@@ -1634,12 +1636,12 @@ class IB:
                 account = accounts[0]
 
             # prepare initializing  requests
-            reqs = {}  # name -> request
+            reqs: Dict = {}  # name -> request
             reqs['positions'] = self.reqPositionsAsync()
             if not readonly and self.client.serverVersion() >= 150:
                 reqs['completed orders'] = self.reqCompletedOrdersAsync(False)
             if account:
-                reqs['account updates'] =self.reqAccountUpdatesAsync(account)
+                reqs['account updates'] = self.reqAccountUpdatesAsync(account)
             if len(accounts) <= self.MaxSyncedSubAccounts:
                 for acc in accounts:
                     reqs[f'account updates for {acc}'] = \
@@ -1664,7 +1666,7 @@ class IB:
 
             self._logger.info('Synchronization complete')
             self.connectedEvent.emit()
-        except Exception:
+        except BaseException:
             self.disconnect()
             raise
         return self
@@ -1767,7 +1769,9 @@ class IB:
             'FullAvailableFunds,FullExcessLiquidity,LookAheadNextChange,'
             'LookAheadInitMarginReq,LookAheadMaintMarginReq,'
             'LookAheadAvailableFunds,LookAheadExcessLiquidity,'
-            'HighestSeverity,DayTradesRemaining,Leverage,$LEDGER:ALL')
+            'HighestSeverity,DayTradesRemaining,DayTradesRemainingT+1,'
+            'DayTradesRemainingT+2,DayTradesRemainingT+3,'
+            'DayTradesRemainingT+4,Leverage,$LEDGER:ALL')
         self.client.reqAccountSummary(reqId, 'All', tags)
         return future
 
@@ -1819,7 +1823,7 @@ class IB:
             return None
 
     async def reqMarketRuleAsync(
-            self, marketRuleId: int) -> Optional[PriceIncrement]:
+            self, marketRuleId: int) -> Optional[List[PriceIncrement]]:
         future = self.wrapper.startReq(f'marketRule-{marketRuleId}')
         try:
             self.client.reqMarketRule(marketRuleId)
