@@ -210,7 +210,10 @@ def allowCtrlC():
 def logToFile(path, level=logging.INFO):
     """Create a log handler that logs to the given file."""
     logger = logging.getLogger()
-    logger.setLevel(level)
+    if logger.handlers:
+        logging.getLogger('ib_insync').setLevel(level)
+    else:
+        logger.setLevel(level)
     formatter = logging.Formatter(
         '%(asctime)s %(name)s %(levelname)s %(message)s')
     handler = logging.FileHandler(path)
@@ -221,15 +224,21 @@ def logToFile(path, level=logging.INFO):
 def logToConsole(level=logging.INFO):
     """Create a log handler that logs to the console."""
     logger = logging.getLogger()
-    logger.setLevel(level)
-    formatter = logging.Formatter(
-        '%(asctime)s %(name)s %(levelname)s %(message)s')
-    handler = logging.StreamHandler()
-    handler.setFormatter(formatter)
-    logger.handlers = [
+    stdHandlers = [
         h for h in logger.handlers
-        if type(h) is not logging.StreamHandler]
-    logger.addHandler(handler)
+        if type(h) is logging.StreamHandler and h.stream is sys.stderr]
+    if stdHandlers:
+        # if a standard stream handler already exists, use it and
+        # set the log level for the ib_insync namespace only
+        logging.getLogger('ib_insync').setLevel(level)
+    else:
+        # else create a new handler
+        logger.setLevel(level)
+        formatter = logging.Formatter(
+            '%(asctime)s %(name)s %(levelname)s %(message)s')
+        handler = logging.StreamHandler()
+        handler.setFormatter(formatter)
+        logger.addHandler(handler)
 
 
 def isNan(x: float) -> bool:
@@ -294,9 +303,10 @@ def run(*awaitables: Awaitable, timeout: float = None):
             return
         loop.run_forever()
         result = None
-        all_tasks = (
-            asyncio.all_tasks(loop)  # type: ignore
-            if sys.version_info >= (3, 7) else asyncio.Task.all_tasks())
+        if sys.version_info >= (3, 7):
+            all_tasks = asyncio.all_tasks(loop)  # type: ignore
+        else:
+            all_tasks = asyncio.Task.all_tasks()  # type: ignore
         if all_tasks:
             # cancel pending tasks
             f = asyncio.gather(*all_tasks)
@@ -453,32 +463,36 @@ def useQt(qtLib: str = 'PyQt5', period: float = 0.01):
     Run combined Qt5/asyncio event loop.
 
     Args:
-        qtLib: Name of Qt library to use, can be 'PyQt5' or 'PySide2'.
+        qtLib: Name of Qt library to use:
+
+          * PyQt5
+          * PyQt6
+          * PySide2
+          * PySide6
         period: Period in seconds to poll Qt.
     """
     def qt_step():
         loop.call_later(period, qt_step)
         if not stack:
-            qloop = QEventLoop()
-            timer = QTimer()
+            qloop = qc.QEventLoop()
+            timer = qc.QTimer()
             timer.timeout.connect(qloop.quit)
             stack.append((qloop, timer))
         qloop, timer = stack.pop()
         timer.start(0)
-        qloop.exec_()
+        qloop.exec() if qtLib == 'PyQt6' else qloop.exec_()
         timer.stop()
         stack.append((qloop, timer))
         qApp.processEvents()
 
-    if qtLib not in ('PyQt5', 'PySide2'):
+    if qtLib not in ('PyQt5', 'PyQt6', 'PySide2', 'PySide6'):
         raise RuntimeError(f'Unknown Qt library: {qtLib}')
-    if qtLib == 'PyQt5':
-        from PyQt5.Qt import QApplication, QTimer, QEventLoop
-    else:
-        from PySide2.QtWidgets import QApplication
-        from PySide2.QtCore import QTimer, QEventLoop
+    from importlib import import_module
+    qc = import_module(qtLib + '.QtCore')
+    qw = import_module(qtLib + '.QtWidgets')
     global qApp
-    qApp = QApplication.instance() or QApplication(sys.argv)  # type: ignore
+    qApp = (qw.QApplication.instance()     # type: ignore
+            or qw.QApplication(sys.argv))  # type: ignore
     loop = asyncio.get_event_loop()
     stack: list = []
     qt_step()
